# Identifications

This directory contains export of the identification process of people and other entities. It can be used to restore the identifications (record linking) after the sources are imported into a new database.